@@ -1,7 +1,7 @@
 
 library("mlt")
 library("lattice")
-library("alabama")
+options(digits = 4)
 
 data("faithful")
 
